@@ -194,12 +194,6 @@ bell_setup(void)
 	dadj = gtk_adjustment_new(bell_duration, 0, 500, 1, 1, 0);
 	dscale = make_scale(_("Duration (ms)"), dadj, &bell_duration, table, 3);
 
-	/* Set sensitivity of scale */
-
-	gtk_widget_set_sensitive(vscale, bell_percent);
-	gtk_widget_set_sensitive(pscale, bell_pitch);
-	gtk_widget_set_sensitive(dscale, bell_duration);
-
 	/* Finished */
 
         gtk_signal_connect (GTK_OBJECT (capplet), "help",
