@@ -30,7 +30,7 @@ left_aligned_button (gchar *label)
 			  0.0, 0.5);
   gtk_misc_set_padding (GTK_MISC (GTK_BIN (button)->child),
 			GNOME_PAD_SMALL, 0);
-
+  
   return button;
 }
 
@@ -61,18 +61,20 @@ cancel_callback ()
         write_initial_keys ();
         write_initial_mime ();
 }
+
 static void
 help_callback ()
 {
         /* Sigh... empty as always */
 }
+
 static void
 init_mime_capplet ()
 {
         GtkWidget *vbox;
         GtkWidget *hbox;
         GtkWidget *button;
-
+        
 	capplet = capplet_widget_new ();
         delete_button = left_aligned_button (_("Delete"));
         gtk_signal_connect (GTK_OBJECT (delete_button), "clicked",
@@ -106,8 +108,10 @@ init_mime_capplet ()
                            GTK_SIGNAL_FUNC(hide_edit_window), NULL);
         gtk_signal_connect(GTK_OBJECT(capplet), "page_shown",
                            GTK_SIGNAL_FUNC(show_edit_window), NULL);
+#if 0
         gtk_signal_connect(GTK_OBJECT(capplet), "help",
                            GTK_SIGNAL_FUNC(help_callback), NULL);
+#endif
 }
 
 int
