@@ -445,13 +445,12 @@ launch_miniview (screensaver_data *sd)
                 close (p[0]);
                 snprintf (xid, 11,"0x%x", (guint)GDK_WINDOW_XWINDOW (monitor->window));
 
-		envpath = getenv("PATH");
-		ctmp = g_strdup_printf("%s%s%s",
-				       envpath?envpath:"",
-				       envpath?":":"",
-				       "/usr/X11R6/lib/xscreensaver");
-		setenv("PATH", ctmp, 1);
-
+		envpath = getenv ("PATH");
+		ctmp = g_strdup_printf ("PATH=%s%s%s",
+                                        envpath ? envpath : "",
+                                        envpath ? ":" : "",
+                                        "/usr/X11R6/lib/xscreensaver");
+		putenv (ctmp);
 		argv = g_strsplit(g_strconcat(sd->demo, " ", sd->windowid, " ", xid, NULL), " ", -1);
 
 		execvp (argv[0], argv);
@@ -675,16 +674,15 @@ dialog_callback (GtkWidget *dialog, gint button, screensaver_data *newsd)
                         snprintf (xid, 11,"0x%x", (guint) GDK_WINDOW_XWINDOW (sswin));
 
                         envpath = getenv("PATH");
-                        ctmp = g_strdup_printf("%s%s%s",
-                                               envpath?envpath:"",
-                                               envpath?":":"",
-                                               "/usr/X11R6/lib/xscreensaver");
-                        setenv("PATH", ctmp, 1);
-                        
+                        ctmp = g_strdup_printf ("PATH=%s%s%s",
+                                                envpath ? envpath : "",
+                                                envpath ? ":" : "",
+                                                "/usr/X11R6/lib/xscreensaver");
+                        putenv (ctmp);
+
                         temp = g_strconcat (newsd->args, " ", newsd->windowid, " ", xid, NULL);
                         argv = g_strsplit (temp, " ", -1);
 
-                        g_print ("argv: %s\n", temp);
                         execvp (argv[0], argv);
                         _exit (1);
                         /* This call should never return */
