@@ -73,7 +73,8 @@ get_settings_frame()
 {
         GtkWidget *retval;
         GtkWidget *vbox, *dpmscheck, *hbox, *label, *tempvbox;
-        GtkWidget *temphbox, *alignment, *ssentry, *pword, *adjustment;
+        GtkWidget *temphbox, *alignment, *ssentry, *pword;
+        GtkAdjustment *adjustment;
         GtkWidget *evbox;
         GtkWidget *nice;
 
@@ -114,9 +115,9 @@ get_settings_frame()
         gtk_box_pack_start (GTK_BOX (temphbox), gtk_label_new (_("Priority:")), FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (tempvbox), temphbox, FALSE, FALSE, 0);
         temphbox = gtk_hbox_new (FALSE, 0);
-	adjustment = GTK_WIDGET(get_and_set_nice ());
+	adjustment = get_and_set_nice ();
 					 
-	nice = gtk_hscale_new (GTK_ADJUSTMENT (adjustment));
+	nice = gtk_hscale_new (adjustment);
         gtk_scale_set_draw_value (GTK_SCALE (nice), FALSE);
         gtk_box_pack_start (GTK_BOX (temphbox), gtk_label_new (_("Low ")), FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (temphbox), nice, TRUE, TRUE, 0);
