@@ -235,6 +235,10 @@ write_state (void)
   gnome_config_set_bool ("TrashMode", trash_changes);
   gnome_config_set_bool ("LogoutPrompt", logout_prompt);
   gnome_config_pop_prefix ();
+
+  /* Set the trash mode in the session manager so it takes effect immediately.
+   */
+  gsm_protocol_set_trash_mode (protocol, trash_changes);
   
   gnome_config_sync ();
 
