@@ -223,8 +223,8 @@ static const gchar *dialog_centered_name [] = {
 
 static WidgetLayout dialog_behavior [] = {
 	{dialog_positions_names, NULL,
-	 gnome_preferences_get_button_layout,
-	 gnome_preferences_set_button_layout,
+	 gnome_preferences_get_dialog_position,
+	 gnome_preferences_set_dialog_position,
 	 NULL},
 	{dialog_types_names, NULL,
 	 gnome_preferences_get_dialog_type,
@@ -344,7 +344,7 @@ make_widget (WidgetLayout *wlay)
 			gtk_object_set_data (GTK_OBJECT (menuitem), "WidgetLayout", wlay);
 			gtk_signal_connect ( GTK_OBJECT (menuitem), "activate",
 					     GTK_SIGNAL_FUNC(option_menu_cb),
-					     GINT_TO_POINTER (i));
+					     GINT_TO_POINTER (i-1));
 			if ( i == wlay->initial_val) {
 				def = i;
 			}
@@ -416,7 +416,6 @@ try_app (CappletLayout *cap_layout)
 					((set_func)cap_layout[i].layout[j].set_func) (GTK_TOGGLE_BUTTON (cap_layout[i].layout[j].widget)->active);
 				}
 			} else {
-
 				((set_func)cap_layout[i].layout[j].set_func) (cap_layout[i].layout[j].cur_val);
 			}
 		}
@@ -468,6 +467,7 @@ try (GtkWidget *capplet, gpointer data)
 		break;
 
 	}
+	gnome_preferences_save ();
 }
 static void
 revert (GtkWidget *capplet, gpointer data)
@@ -483,6 +483,7 @@ revert (GtkWidget *capplet, gpointer data)
 		revert_app (mdi_options);
 		break;
 	}
+	gnome_preferences_save ();
 }
 
 static void
