@@ -14,7 +14,7 @@ extern GtkWidget *notebook;
 extern GtkWidget *create_exit_dialog();
 extern GList *capplet_list;
 static GtkWidget *about = NULL;
-
+extern gint destroying;
 /* this is meant to be called with a foreach to make a list of all modified nodes. */
 void
 create_templist (node_data *data, GList **list)
@@ -44,7 +44,8 @@ void
 exit_dialog_ok_callback(GtkWidget *widget, gpointer data)
 {
         revert_all ();
-        gtk_widget_destroy (main_window);
+        destroying = TRUE;
+        gtk_widget_destroy (notebook);
         control_center_corba_gtk_main_quit();
 }
 void
