@@ -14,6 +14,7 @@ extern GtkWidget *hack_widget;
 extern gchar *ior;
 static gint current_page = 0;
 static gint id = 0;
+gint destroying = FALSE;
 GList *capplet_list = NULL;
 extern CORBA_Environment ev;
 
@@ -289,6 +290,9 @@ capplet_close_callback (GtkWidget *widget, gpointer data)
         node_data *nd = (node_data *) data;
         GtkStyle *style;
 
+        if (destroying)
+                return;
+
         if (nd->socket != NULL) {
                 nd->socket = NULL;
                 close_capplet (TRUE, nd);
