@@ -164,10 +164,10 @@ capplet_widget_new ()
 
         retval = CAPPLET_WIDGET (gtk_type_new (capplet_widget_get_type()));
         /* we should set this: */
-        retval->capid = get_capid ();
+        retval->capid = _capplet_int_get_capid ();
 
-        retval->control_center_id = get_ccid (retval->capid);
-        gtk_plug_construct (GTK_PLUG (retval), get_xid (retval->capid));
+        retval->control_center_id = _capplet_int_get_ccid (retval->capid);
+        gtk_plug_construct (GTK_PLUG (retval), _capplet_int_get_xid (retval->capid));
 
         return GTK_WIDGET (retval);
 }
@@ -178,8 +178,8 @@ capplet_widget_multi_new (gint capid)
 
         retval = CAPPLET_WIDGET (gtk_type_new (capplet_widget_get_type()));
         retval->capid = capid;
-        retval->control_center_id = get_ccid (retval->capid);
-        gtk_plug_construct (GTK_PLUG (retval), get_xid (retval->capid));
+        retval->control_center_id = _capplet_int_get_ccid (retval->capid);
+        gtk_plug_construct (GTK_PLUG (retval), _capplet_int_get_xid (retval->capid));
         
         return GTK_WIDGET (retval);
 }
@@ -211,9 +211,9 @@ gnome_capplet_init (const char *app_id, const char *app_version,
 
         if(orbptr)
                 return 0;
-        else if (session_initialization_requested_p ())
+        else if (_capplet_int_session_initialization_requested_p ())
                 return 1;
-        else if (session_ignore_requested_p ())
+        else if (_capplet_int_session_ignore_requested_p ())
                 return 2;
         else
                 return -1;
@@ -250,7 +250,19 @@ void
 _capplet_widget_server_help(gint id)
 {
         GtkWidget *capplet = get_widget_by_id (id);
-        gtk_signal_emit_by_name(GTK_OBJECT (capplet) ,"help");
+        guint sigid;
+
+        sigid = gtk_signal_lookup("help", GTK_OBJECT_TYPE(capplet));
+        if(gtk_signal_handler_pending(GTK_OBJECT(capplet), sigid, FALSE)) {
+                gtk_signal_emit(GTK_OBJECT (capplet), sigid);
+        } else {
+                GtkWidget *mbox;
+
+                mbox =
+                        gnome_message_box_new(_("Sorry, no help is available for these settings."), GNOME_MESSAGE_BOX_ERROR,
+                                              _("Close"), NULL);
+                gtk_widget_show(mbox);
+        }
 }
 void
 _capplet_widget_server_new_multi_capplet(gint id, gint capid)
