@@ -37,6 +37,8 @@ struct _CappletWidgetClass
         void (* cancel)		(CappletWidget *capplet);
         void (* help) 		(CappletWidget *capplet);
         void (* new_multi_capplet) 	(CappletWidget *capplet);
+        void (* page_hidden)	(CappletWidget *capplet);
+        void (* page_shown)	(CappletWidget *capplet);
 };
 
 guint           capplet_widget_get_type       	(void);
