@@ -86,7 +86,6 @@ control_center_corba_gtk_init(gint *argc, char **argv)
 
         poa = CORBA_ORB_resolve_initial_references(orb, "RootPOA", &ev);
         POA_GNOME_control_center__init(&poa_control_center_servant, &ev);
-        PortableServer_POAManager_activate(PortableServer_POA__get_the_POAManager(poa, &ev), &ev);
 
         PortableServer_POA_activate_object_with_id(poa, 
                                                    &objid, &poa_control_center_servant, &ev);
@@ -119,8 +118,11 @@ control_center_corba_gtk_init(gint *argc, char **argv)
 void
 control_center_corba_gtk_main (gint *argc, char **argv)
 {
-        if(!orb)
+        if(!orb) {
                 control_center_corba_gtk_init( argc, argv);
+        }
+        PortableServer_POAManager_activate(PortableServer_POA__get_the_POAManager(CORBA_ORB_resolve_initial_references(orb, "RootPOA", &ev), &ev), &ev);
+
         gtk_main();
 }
 
@@ -183,7 +185,7 @@ find_capplet (GtkCTree     *ctree,
         gchar *name = (gchar*) (((GSList *)list)->next->data);
         gint capid = (gint) (((GSList *)list)->next->next->data);
         gint i;
-        
+
         if (*data_pointer != NULL)
                 return;
         if (nd->gde->exec && nd->gde->exec[0]
@@ -234,13 +236,14 @@ void server_register_capplet_new (PortableServer_Servant servant,
         ugly_list = g_slist_prepend (ugly_list, (gpointer) capid);
         ugly_list = g_slist_prepend (ugly_list, (gpointer) name);
         ugly_list = g_slist_prepend (ugly_list, &nd);
+        
         /* First thing we want to do is find the entry, if possible */
         gtk_ctree_post_recursive (GTK_CTREE (tree),NULL, find_capplet, ugly_list);
         if ((nd == NULL) || (nd->id != -1)) {
                 /* Abort, Abort */
                 *xid = 0;
                 *newid = -1;
-                nd->state = CAPPLET_INACTIVE;
+
                 return;
         }
         nd->capplet = CORBA_Object_duplicate (cap, &ev);
