@@ -20,9 +20,6 @@ void merge_nodes (GNode *node1, GNode *node2);
 GtkWidget *generate_tree ();
 gint button_press (GtkCTree *ctree, GdkEventButton *event, gpointer data);
 
-/* callbacks */
-void selected_row_callback (GtkWidget *widget, GtkCTreeNode *node, gint column, gpointer unseen);
-        
 typedef enum
 {
         CAPPLET_INACTIVE,
